pywws.ToTwitter — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »
- Python programs and modules »

# pywws.ToTwitter

Post a message to Twitter

    usage: python RunModule.py ToTwitter [options] data_dir file
    options are:
     -h | --help  display this help
    data_dir is the root directory of the weather data
    file is the text file to be uploaded

This module posts a brief message to Twitter. Before posting to Twitter you need to set up an account and then authorise pywws by running the `TwitterAuth` program. See How to configure pywws to post messages to Twitter for detailed instructions.

Functions

`main`([argv]) |

Classes

`ToTwitter`(params) |

class `pywws.ToTwitter.` `ToTwitter`(params)
  `Upload`(tweet)
  `UploadFile`(file)

`pywws.ToTwitter.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »
- Python programs and modules »